==> haskell-unagi-streams-0.2.7-154.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-unagi-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unagi-streams
version:              0.2.7
visibility:           public
id:                   unagi-streams-0.2.7-KCaD7zOYOgkFWVaPiTOr0I
key:                  unagi-streams-0.2.7-KCaD7zOYOgkFWVaPiTOr0I
license:              BSD-3-Clause
copyright:            Bitnomial, Inc. (c) 2016
maintainer:           luke@bitnomial.com
author:               Luke Hoersten
homepage:             https://github.com/bitnomial/unagi-streams
synopsis:             Unagi Chan IO-Streams
description:
    Io-streams chans implemented underneath with
    unagi-chans. This library is a straight port of
    the default io-streams chan implementation.

category:             IO-Streams, Concurrency
abi:                  1f986ff8ed4489225ded4e1bf87db36a
exposed:              True
exposed-modules:
    System.IO.Streams.Concurrent.Unagi
    System.IO.Streams.Concurrent.Unagi.Bounded

import-dirs:          /usr/lib/ghc-9.6.6/site-local/unagi-streams-0.2.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/unagi-streams-0.2.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/unagi-streams-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unagi-streams
hs-libraries:         HSunagi-streams-0.2.7-KCaD7zOYOgkFWVaPiTOr0I
depends:
    base-4.18.2.1 io-streams-1.5.2.2-GBIxq3Y3ahG4K7ipZI07Kf
    unagi-chan-0.4.1.4-844mNNQinvwHdBlGKCM4D5

haddock-interfaces:
    /usr/share/doc/haskell-unagi-streams/html/unagi-streams.haddock

haddock-html:         /usr/share/doc/haskell-unagi-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unagi-streams-0.2.7-155-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-unagi-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unagi-streams
version:              0.2.7
visibility:           public
id:                   unagi-streams-0.2.7-E7ae8BgkJxoJ20J9gQ4bna
key:                  unagi-streams-0.2.7-E7ae8BgkJxoJ20J9gQ4bna
license:              BSD-3-Clause
copyright:            Bitnomial, Inc. (c) 2016
maintainer:           luke@bitnomial.com
author:               Luke Hoersten
homepage:             https://github.com/bitnomial/unagi-streams
synopsis:             Unagi Chan IO-Streams
description:
    Io-streams chans implemented underneath with
    unagi-chans. This library is a straight port of
    the default io-streams chan implementation.

category:             IO-Streams, Concurrency
abi:                  0a5b433b64250876c005d1ea281fef6d
exposed:              True
exposed-modules:
    System.IO.Streams.Concurrent.Unagi
    System.IO.Streams.Concurrent.Unagi.Bounded

import-dirs:          /usr/lib/ghc-9.6.6/site-local/unagi-streams-0.2.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/unagi-streams-0.2.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/unagi-streams-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unagi-streams
hs-libraries:         HSunagi-streams-0.2.7-E7ae8BgkJxoJ20J9gQ4bna
depends:
    base-4.18.2.1 io-streams-1.5.2.2-6dLtg5IQso2LoK2aAZRuxZ
    unagi-chan-0.4.1.4-2RX1PselkPr3pRuvMoC0R9

haddock-interfaces:
    /usr/share/doc/haskell-unagi-streams/html/unagi-streams.haddock

haddock-html:         /usr/share/doc/haskell-unagi-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
